@@ -9,6 +9,9 @@
 #include "stats.h"
 #include "filterresult.h"
 #include <fstream>
+#include <atomic>
+#include "common.h"
+#include "util.h"
 
 using namespace std;
 
@@ -16,8 +19,8 @@ class HtmlReporter{
 public:
     HtmlReporter(Options* opt);
     ~HtmlReporter();
-    void setDupHist(int* dupHist, double* dupMeanGC, double dupRate);
-    void setInsertHist(long* insertHist, int insertSizePeak);
+    void setDup(double dupRate);
+    void setInsertHist(atomic_long* insertHist, int insertSizePeak);
     void report(FilterResult* result, Stats* preStats1, Stats* postStats1, Stats* preStats2 = NULL, Stats* postStats2 = NULL);
 
     static void outputRow(ofstream& ofs, string key, long value);
@@ -39,9 +42,9 @@ private:
     int* mDupHist;
     double* mDupMeanGC;
     double mDupRate;
-    long* mInsertHist;
+    atomic_long* mInsertHist;
     int mInsertSizePeak;
 };
 
 
-#endif
\ No newline at end of file
+#endif
